# simple_linear_regression

Description.
The package regression_results is used to:

    Model Analysis :
    	- Plot fit model
        - statistical results table

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install regression_results

```bash
pip install regression_results
```

## Usage

```python
 import plot_regression.plot_map as mp

mp.plot_regression(data['GPA'],data['SAT']);
```

<img width="auto" src="https://github.com/jeffersonAsilva/Gera-o-Tech-Unimed-BH_criacao_pacotes/blob/main/linear.png">

```python
 import plot_regression.results_table as tb

tb.result_table(data['GPA'],data['SAT'])
```

<img width="auto" src="https://github.com/jeffersonAsilva/Gera-o-Tech-Unimed-BH_criacao_pacotes/blob/main/table3.png">

## Author

Jefferson A Silva

## License

[MIT](https://choosealicense.com/licenses/mit/)
